@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2015, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -75,12 +75,12 @@
 // Return a node which is more "ideal" than the current node.
 // Move constants to the right.
 Node *CMoveNode::Ideal(PhaseGVN *phase, bool can_reshape) {
-  if (in(0) != NULL && remove_dead_region(phase, can_reshape)) {
+  if (in(0) != nullptr && remove_dead_region(phase, can_reshape)) {
     return this;
   }
   // Don't bother trying to transform a dead node
-  if (in(0) != NULL && in(0)->is_top()) {
-    return NULL;
+  if (in(0) != nullptr && in(0)->is_top()) {
+    return nullptr;
   }
   assert(in(Condition) != this &&
          in(IfFalse)   != this &&
@@ -88,14 +88,14 @@ Node *CMoveNode::Ideal(PhaseGVN *phase, bool can_reshape) {
   if (phase->type(in(Condition)) == Type::TOP ||
       phase->type(in(IfFalse))   == Type::TOP ||
       phase->type(in(IfTrue))    == Type::TOP) {
-    return NULL;
+    return nullptr;
   }
   // Canonicalize the node by moving constants to the right input.
   if (in(Condition)->is_Bool() && phase->type(in(IfFalse))->singleton() && !phase->type(in(IfTrue))->singleton()) {
     BoolNode* b = in(Condition)->as_Bool()->negate(phase);
     return make(in(Control), phase->transform(b), in(IfTrue), in(IfFalse), _type);
   }
-  return NULL;
+  return nullptr;
 }
 
 //------------------------------is_cmove_id------------------------------------
@@ -108,7 +108,7 @@ Node *CMoveNode::is_cmove_id( PhaseTransform *phase, Node *cmp, Node *t, Node *f
        // Give up this identity check for floating points because it may choose incorrect
        // value around 0.0 and -0.0
        if ( cmp->Opcode()==Op_CmpF || cmp->Opcode()==Op_CmpD )
-       return NULL;
+       return nullptr;
        // Check for "(t==f)?t:f;" and replace with "f"
        if( b->_test._test == BoolTest::eq )
        return f;
@@ -117,7 +117,7 @@ Node *CMoveNode::is_cmove_id( PhaseTransform *phase, Node *cmp, Node *t, Node *f
        if( b->_test._test == BoolTest::ne )
        return t;
      }
-  return NULL;
+  return nullptr;
 }
 
 //------------------------------Identity---------------------------------------
@@ -180,7 +180,7 @@ CMoveNode *CMoveNode::make(Node *c, Node *bol, Node *left, Node *right, const Ty
     case T_NARROWOOP: return new CMoveNNode( c, bol, left, right, t );
     default:
     ShouldNotReachHere();
-    return NULL;
+    return nullptr;
   }
 }
 
@@ -214,26 +214,26 @@ Node *CMoveINode::Ideal(PhaseGVN *phase, bool can_reshape) {
   if( phase->type(in(IfFalse)) == TypeInt::ZERO && phase->type(in(IfTrue)) == TypeInt::ONE ) {
     flip = 1 - flip;
   } else if( phase->type(in(IfFalse)) == TypeInt::ONE && phase->type(in(IfTrue)) == TypeInt::ZERO ) {
-  } else return NULL;
+  } else return nullptr;
 
   // Check for eq/ne test
-  if( !in(1)->is_Bool() ) return NULL;
+  if( !in(1)->is_Bool() ) return nullptr;
   BoolNode *bol = in(1)->as_Bool();
   if( bol->_test._test == BoolTest::eq ) {
   } else if( bol->_test._test == BoolTest::ne ) {
     flip = 1-flip;
-  } else return NULL;
+  } else return nullptr;
 
   // Check for vs 0 or 1
-  if( !bol->in(1)->is_Cmp() ) return NULL;
+  if( !bol->in(1)->is_Cmp() ) return nullptr;
   const CmpNode *cmp = bol->in(1)->as_Cmp();
   if( phase->type(cmp->in(2)) == TypeInt::ZERO ) {
   } else if( phase->type(cmp->in(2)) == TypeInt::ONE ) {
     // Allow cmp-vs-1 if the other input is bounded by 0-1
     if( phase->type(cmp->in(1)) != TypeInt::BOOL )
-    return NULL;
+    return nullptr;
     flip = 1 - flip;
-  } else return NULL;
+  } else return nullptr;
 
   // Convert to a bool (flipped)
   // Build int->bool conversion
@@ -258,7 +258,7 @@ Node *CMoveFNode::Ideal(PhaseGVN *phase, bool can_reshape) {
   int  phi_x_idx = 0;           // Index of phi input where to find naked x
 
   // Find the Bool
-  if( !in(1)->is_Bool() ) return NULL;
+  if( !in(1)->is_Bool() ) return nullptr;
   BoolNode *bol = in(1)->as_Bool();
   // Check bool sense
   switch( bol->_test._test ) {
@@ -266,13 +266,13 @@ Node *CMoveFNode::Ideal(PhaseGVN *phase, bool can_reshape) {
     case BoolTest::le: cmp_zero_idx = 2; phi_x_idx = IfFalse; break;
     case BoolTest::gt: cmp_zero_idx = 2; phi_x_idx = IfTrue;  break;
     case BoolTest::ge: cmp_zero_idx = 1; phi_x_idx = IfFalse; break;
-    default:           return NULL;                           break;
+    default:           return nullptr;                        break;
   }
 
   // Find zero input of CmpF; the other input is being abs'd
   Node *cmpf = bol->in(1);
-  if( cmpf->Opcode() != Op_CmpF ) return NULL;
-  Node *X = NULL;
+  if( cmpf->Opcode() != Op_CmpF ) return nullptr;
+  Node *X = nullptr;
   bool flip = false;
   if( phase->type(cmpf->in(cmp_zero_idx)) == TypeF::ZERO ) {
     X = cmpf->in(3 - cmp_zero_idx);
@@ -281,18 +281,18 @@ Node *CMoveFNode::Ideal(PhaseGVN *phase, bool can_reshape) {
     X = cmpf->in(cmp_zero_idx);
     flip = true;
   } else {
-    return NULL;
+    return nullptr;
   }
 
   // If X is found on the appropriate phi input, find the subtract on the other
-  if( X != in(phi_x_idx) ) return NULL;
+  if( X != in(phi_x_idx) ) return nullptr;
   int phi_sub_idx = phi_x_idx == IfTrue ? IfFalse : IfTrue;
   Node *sub = in(phi_sub_idx);
 
   // Allow only SubF(0,X) and fail out for all others; NegF is not OK
   if( sub->Opcode() != Op_SubF ||
      sub->in(2) != X ||
-     phase->type(sub->in(1)) != TypeF::ZERO ) return NULL;
+     phase->type(sub->in(1)) != TypeF::ZERO ) return nullptr;
 
   Node *abs = new AbsFNode( X );
   if( flip )
@@ -314,7 +314,7 @@ Node *CMoveDNode::Ideal(PhaseGVN *phase, bool can_reshape) {
   int  phi_x_idx = 0;           // Index of phi input where to find naked x
 
   // Find the Bool
-  if( !in(1)->is_Bool() ) return NULL;
+  if( !in(1)->is_Bool() ) return nullptr;
   BoolNode *bol = in(1)->as_Bool();
   // Check bool sense
   switch( bol->_test._test ) {
@@ -322,13 +322,13 @@ Node *CMoveDNode::Ideal(PhaseGVN *phase, bool can_reshape) {
     case BoolTest::le: cmp_zero_idx = 2; phi_x_idx = IfFalse; break;
     case BoolTest::gt: cmp_zero_idx = 2; phi_x_idx = IfTrue;  break;
     case BoolTest::ge: cmp_zero_idx = 1; phi_x_idx = IfFalse; break;
-    default:           return NULL;                           break;
+    default:           return nullptr;                        break;
   }
 
   // Find zero input of CmpD; the other input is being abs'd
   Node *cmpd = bol->in(1);
-  if( cmpd->Opcode() != Op_CmpD ) return NULL;
-  Node *X = NULL;
+  if( cmpd->Opcode() != Op_CmpD ) return nullptr;
+  Node *X = nullptr;
   bool flip = false;
   if( phase->type(cmpd->in(cmp_zero_idx)) == TypeD::ZERO ) {
     X = cmpd->in(3 - cmp_zero_idx);
@@ -337,18 +337,18 @@ Node *CMoveDNode::Ideal(PhaseGVN *phase, bool can_reshape) {
     X = cmpd->in(cmp_zero_idx);
     flip = true;
   } else {
-    return NULL;
+    return nullptr;
   }
 
   // If X is found on the appropriate phi input, find the subtract on the other
-  if( X != in(phi_x_idx) ) return NULL;
+  if( X != in(phi_x_idx) ) return nullptr;
   int phi_sub_idx = phi_x_idx == IfTrue ? IfFalse : IfTrue;
   Node *sub = in(phi_sub_idx);
 
   // Allow only SubD(0,X) and fail out for all others; NegD is not OK
   if( sub->Opcode() != Op_SubD ||
      sub->in(2) != X ||
-     phase->type(sub->in(1)) != TypeD::ZERO ) return NULL;
+     phase->type(sub->in(1)) != TypeD::ZERO ) return nullptr;
 
   Node *abs = new AbsDNode( X );
   if( flip )
@@ -364,7 +364,7 @@ Node* MoveNode::Ideal(PhaseGVN* phase, bool can_reshape) {
     // Fold reinterpret cast into memory operation:
     //    MoveX2Y (LoadX mem) => LoadY mem
     LoadNode* ld = in(1)->isa_Load();
-    if (ld != NULL && (ld->outcnt() == 1)) { // replace only
+    if (ld != nullptr && (ld->outcnt() == 1)) { // replace only
       const Type* rt = bottom_type();
       if (ld->has_reinterpret_variant(rt)) {
         if (phase->C->post_loop_opts_phase()) {
@@ -375,7 +375,7 @@ Node* MoveNode::Ideal(PhaseGVN* phase, bool can_reshape) {
       }
     }
   }
-  return NULL;
+  return nullptr;
 }
 
 Node* MoveNode::Identity(PhaseGVN* phase) {
